==> react-initial-props-2.7.1-beta.0.tgz: package/lib/withInitialProps.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useEffect, useState } from 'react'; // This HoC creates the PageComponent prepared for the Client Side Rendering
// It renders a placeholder, if any specified as `renderLoading` on the PageComponent
// Also, executes the getInitialProps to retrieve the initialProps and then
// Renders the component with the initialProps, hiding the placeholder

export default (function (_ref) {
  var context = _ref.context,
      routeInfo = _ref.routeInfo;
  return function (Page) {
    var ClientPage = function ClientPage(props) {
      var _useState = useState({
        initialProps: {},
        isLoading: true
      }),
          _useState2 = _slicedToArray(_useState, 2),
          _useState2$ = _useState2[0],
          initialProps = _useState2$.initialProps,
          isLoading = _useState2$.isLoading,
          setState = _useState2[1];

      useEffect(function () {
        Page.getInitialProps({
          context: context,
          routeInfo: routeInfo
        }).then(function (initialProps) {
          setState({
            initialProps: initialProps,
            isLoading: false
          });
        })["catch"](function (error) {
          setState({
            initialProps: {
              error: error
            },
            isLoading: false
          });
        });
      }, []);

      var renderLoading = function renderLoading() {
        // check if the page has a renderLoading method, if not, just render nothing
        return Page.renderLoading ? Page.renderLoading() : null;
      };

      return isLoading ? renderLoading() : React.createElement(Page, Object.assign({}, initialProps, props));
    }; // add ClientPage to name of the component


    ClientPage.displayName = "ClientPage(" + Page.displayName + ")"; // return the page

    return ClientPage;
  };
});

==> react-initial-props-2.8.0-beta.0.tgz: package/lib/withInitialProps.js <==
import React, { useEffect, useState } from 'react'; // This HoC creates the PageComponent prepared for the Client Side Rendering
// It renders a placeholder, if any specified as `renderLoading` on the PageComponent
// Also, executes the getInitialProps to retrieve the initialProps and then
// Renders the component with the initialProps, hiding the placeholder

export default (function (_ref) {
  var context = _ref.context,
      routeInfo = _ref.routeInfo;
  return function (Page) {
    var ClientPage = function ClientPage(props) {
      var _useState = useState({
        initialProps: {},
        isLoading: true
      }),
          _useState$ = _useState[0],
          initialProps = _useState$.initialProps,
          isLoading = _useState$.isLoading,
          setState = _useState[1];

      useEffect(function () {
        Page.getInitialProps({
          context: context,
          routeInfo: routeInfo
        }).then(function (initialProps) {
          setState({
            initialProps: initialProps,
            isLoading: false
          });
        })["catch"](function (error) {
          setState({
            initialProps: {
              error: error
            },
            isLoading: false
          });
        });
      }, []);

      var renderLoading = function renderLoading() {
        // check if the page has a renderLoading method, if not, just render nothing
        return Page.renderLoading ? Page.renderLoading({
          context: context,
          routeInfo: routeInfo
        }) : null;
      };

      return isLoading ? renderLoading() : React.createElement(Page, Object.assign({}, initialProps, props));
    }; // add ClientPage to name of the component


    ClientPage.displayName = "ClientPage(" + Page.displayName + ")"; // return the page

    return ClientPage;
  };
});
